@@ -1,6 +1,12 @@
 from .service import Service, ConfigurableService, run
 from .util import waitany, parse_address
 
+from . import _meta
+
+
+__version__ = _meta.version
+__version_info__ = _meta.version_info
+
 
 __all__ = [
     'ConfigurableService',
