@@ -1,4 +1,5 @@
 import functools
+import sys
 
 import gevent
 import logbook
@@ -34,6 +35,12 @@ class Service(pyee.EventEmitter):
         self.spawned_greenlets = []
         self._logger = None
 
+    def __del__(self):
+        try:
+            self.stop()
+        except:
+            pass
+
     @util.cachedproperty
     def logger(self):
         return self.get_logger()
@@ -73,14 +80,8 @@ class Service(pyee.EventEmitter):
             def wrapper(*args, **kwargs):
                 try:
                     return func(*args, **kwargs)
-                except Exception as e:
-                    self.logger.exception(
-                        '{}(*{!r}), **{!r})'.format(func, args, kwargs)
-                    )
-
-                    self.emit('error', e)
-
-                    raise
+                except Exception:
+                    self.emit('error', *sys.exc_info())
 
             return wrapper
 
@@ -242,6 +243,17 @@ class Config(object):
 
         return self.expand(value)
 
+    def setdefault(self, key, value):
+        missing = object()
+
+        original_value = self.get(key, missing)
+
+        if original_value is missing:
+            self.config[key] = value
+
+    def __getitem__(self, key, default=None):
+        return self.get(key, default=default)
+
 
 class ConfigurableService(Service):
     """
